@@ -4,6 +4,7 @@
 @created: 20.07.20
 @author: felix
 """
+import inspect
 import logging
 import os
 from types import MethodType
@@ -13,8 +14,16 @@ from strongtyping.config import SEVERITY_LEVEL
 
 logger = logging.getLogger(__name__)
 
+ORIGINAL_DUCK_TYPES = {
+    int: [int, float, complex],
+    float: [float, complex],
+    bytearray: [bytearray, bytes],
+}
+
 
 def remove_subclass(args, subclass):
+    if len(args) == 1:
+        return args
     cls = args[0] if subclass else None
     if cls is not None:
         args = args[1:]
